
# ------------------------------------------------------------------------------
#
# global constants
#
UMGR_SCHEDULING_QUEUE          = 'umgr_scheduling_queue'
UMGR_STAGING_INPUT_QUEUE       = 'umgr_staging_input_queue'
UMGR_STAGING_OUTPUT_QUEUE      = 'umgr_staging_output_queue'

UMGR_SCHEDULING_COMPONENT      = 'UmgrSchedulingComponent'
UMGR_STAGING_INPUT_COMPONENT   = 'UmgrStagingInputComponent'
UMGR_STAGING_OUTPUT_COMPONENT  = 'UmgrStagingOutputComponent'
UMGR_UPDATE_WORKER             = 'UmgrUpdateWorker'

AGENT_STAGING_INPUT_QUEUE      = 'agent_staging_input_queue'
AGENT_SCHEDULING_QUEUE         = 'agent_scheduling_queue'
AGENT_EXECUTING_QUEUE          = 'agent_executing_queue'
AGENT_STAGING_OUTPUT_QUEUE     = 'agent_staging_output_queue'

AGENT_STAGING_INPUT_COMPONENT  = 'AgentStagingInputComponent'
AGENT_SCHEDULING_COMPONENT     = 'AgentSchedulingComponent'
AGENT_EXECUTING_COMPONENT      = 'AgentExecutingComponent'
AGENT_STAGING_OUTPUT_COMPONENT = 'AgentStagingOutputComponent'
AGENT_UPDATE_WORKER            = 'AgentUpdateWorker'
AGENT_HEARTBEAT_WORKER         = 'AgentHeartbeatWorker'

PMGR_LAUNCHING_QUEUE           = 'pmgr_launching_queue'

PMGR_LAUNCHING_COMPONENT       = 'PmgrLaunchingComponent'

UMGR_STATE_PUBSUB              = 'umgr_state_pubsub'

AGENT_UNSCHEDULE_PUBSUB        = 'agent_unschedule_pubsub'
AGENT_RESCHEDULE_PUBSUB        = 'agent_reschedule_pubsub'
AGENT_COMMAND_PUBSUB           = 'agent_command_pubsub'
AGENT_STATE_PUBSUB             = 'agent_state_pubsub'

